@@ -19,13 +19,9 @@ class PathManagerSingleton:
         self._set_path(config, git_config=False)
         self._set_path(git_config, git_config=True)
 
-    def get_relative_path_from_project_root(
-        self, path: str, append_root_folder=False
-    ):
+    def get_relative_path_from_project_root(self, path: str, append_root_folder=False):
         if self._config_path is None:
-            raise Exception(
-                "Should call setup method before any other function"
-            )
+            raise Exception("Should call setup method before any other function")
         try:
             current_config_path = (
                 self._config_root_folder_path
